==> mgv-2.2.1.tar.gz: mgv-2.2.1/strdefs.c <==
/*
 * strdefs.c
 *	Extra string defs for MGv.
 *
 * Copyright (C) 1996  Eric A. Howe
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Authors:	Matthew D. Francey
 *		Eric A. Howe (mu@echo-on.net)
 */
#include	<wlib/rcs.h>
MU_ID("$Mu: mgv/strdefs.c,v 1.17 $")

const char mgv_strdefs[] = {
'a','n','t','i','a','l','i','a','s','E','P','S','\0',
'A','n','t','i','a','l','i','a','s','E','P','S','\0',
'a','u','t','o','H','e','i','g','h','t','\0',
'A','u','t','o','H','e','i','g','h','t','\0',
'a','u','t','o','W','i','d','t','h','\0',
'A','u','t','o','W','i','d','t','h','\0',
'c','o','n','f','i','r','m','E','x','i','t','\0',
'C','o','n','f','i','r','m','E','x','i','t','\0',
'd','e','c','o','m','p','r','e','s','s','\0',
'D','e','c','o','m','p','r','e','s','s','\0',
'd','e','f','a','u','l','t','P','a','g','e','M','e','d','i','a','\0',
'D','e','f','a','u','l','t','P','a','g','e','M','e','d','i','a','\0',
'P','a','g','e','M','e','d','i','a','\0',
'h','i','d','e','L','o','g','\0',
'H','i','d','e','L','o','g','\0',
'h','i','d','e','M','e','n','u','B','a','r','\0',
'H','i','d','e','M','e','n','u','B','a','r','\0',
'h','i','d','e','P','a','g','e','L','i','s','t','\0',
'H','i','d','e','P','a','g','e','L','i','s','t','\0',
'h','i','d','e','S','t','a','t','u','s','L','i','n','e','\0',
'H','i','d','e','S','t','a','t','u','s','L','i','n','e','\0',
'k','i','l','l','C','h','i','l','d','r','e','n','A','t','E','x','i','t','\0',
'K','i','l','l','C','h','i','l','d','r','e','n','A','t','E','x','i','t','\0',
'm','a','g','i','c','R','e','s','i','s','t','a','n','c','e','\0',
'M','a','g','i','c','R','e','s','i','s','t','a','n','c','e','\0',
'p','r','i','n','t','C','o','m','m','a','n','d','\0',
'P','r','i','n','t','C','o','m','m','a','n','d','\0',
'p','r','i','n','t','e','r','\0',
'P','r','i','n','t','e','r','\0',
'r','e','s','e','t','S','c','r','o','l','l','B','a','r','s','\0',
'R','e','s','e','t','S','c','r','o','l','l','B','a','r','s','\0',
'r','e','t','i','c','u','l','e','F','o','r','e','g','r','o','u','n','d','\0',
'R','e','t','i','c','u','l','e','F','o','r','e','g','r','o','u','n','d','\0',
'r','e','t','i','c','u','l','e','L','i','n','e','W','i','d','t','h','\0',
'R','e','t','i','c','u','l','e','L','i','n','e','W','i','d','t','h','\0',
's','h','o','w','L','a','b','e','l','s','\0',
'S','h','o','w','L','a','b','e','l','s','\0',
's','h','o','w','P','a','g','e','N','u','m','b','e','r','s','\0',
'S','h','o','w','P','a','g','e','N','u','m','b','e','r','s','\0',
't','e','m','p','D','i','r','\0',
'T','e','m','p','D','i','r','\0',
'm','a','g','i','c','S','c','r','o','l','l','i','n','g','\0',
'M','a','g','i','c','S','c','r','o','l','l','i','n','g','\0',
's','m','o','o','t','h','S','c','r','o','l','l','i','n','g','\0',
'S','m','o','o','t','h','S','c','r','o','l','l','i','n','g','\0',
's','m','o','o','t','h','n','e','s','s','\0',
'S','m','o','o','t','h','n','e','s','s','\0',
'm','a','g','s','t','e','p','\0',
'M','a','g','s','t','e','p','\0',
's','m','a','r','t','S','i','z','i','n','g','\0',
'S','m','a','r','t','S','i','z','i','n','g','\0',
'w','m','W','i','d','t','h','\0',
'W','m','W','i','d','t','h','\0',
'w','m','H','e','i','g','h','t','\0',
'W','m','H','e','i','g','h','t','\0',
's','c','r','o','l','l','P','e','r','c','e','n','t','a','g','e','\0',
'S','c','r','o','l','l','P','e','r','c','e','n','t','a','g','e','\0',
's','t','r','i','n','g','B','a','d','A','r','g','u','m','e','n','t','\0',
'S','t','r','i','n','g','B','a','d','A','r','g','u','m','e','n','t','\0',
's','t','r','i','n','g','B','a','d','V','e','r','s','i','o','n','\0',
'S','t','r','i','n','g','B','a','d','V','e','r','s','i','o','n','\0',
's','t','r','i','n','g','C','a','n','t','A','l','l','o','c','P','i','x','m','a','p','\0',
'S','t','r','i','n','g','C','a','n','t','A','l','l','o','c','P','i','x','m','a','p','\0',
's','t','r','i','n','g','C','a','n','t','D','e','c','o','m','p','r','e','s','s','\0',
'S','t','r','i','n','g','C','a','n','t','D','e','c','o','m','p','r','e','s','s','\0',
's','t','r','i','n','g','C','a','n','t','H','i','d','e','M','e','n','u','\0',
'S','t','r','i','n','g','C','a','n','t','H','i','d','e','M','e','n','u','\0',
's','t','r','i','n','g','C','a','n','t','O','p','e','n','\0',
'S','t','r','i','n','g','C','a','n','t','O','p','e','n','\0',
's','t','r','i','n','g','C','a','n','t','P','r','i','n','t','\0',
'S','t','r','i','n','g','C','a','n','t','P','r','i','n','t','\0',
's','t','r','i','n','g','E','r','r','o','r','\0',
'S','t','r','i','n','g','E','r','r','o','r','\0',
's','t','r','i','n','g','F','i','l','e','E','x','i','s','t','s','\0',
'S','t','r','i','n','g','F','i','l','e','E','x','i','s','t','s','\0',
's','t','r','i','n','g','I','n','t','e','r','p','D','o','n','e','\0',
'S','t','r','i','n','g','I','n','t','e','r','p','D','o','n','e','\0',
's','t','r','i','n','g','I','n','t','e','r','p','F','a','i','l','e','d','\0',
'S','t','r','i','n','g','I','n','t','e','r','p','F','a','i','l','e','d','\0',
's','t','r','i','n','g','M','e','s','s','a','g','e','\0',
'S','t','r','i','n','g','M','e','s','s','a','g','e','\0',
's','t','r','i','n','g','N','o','C','o','o','r','d','i','n','a','t','e','s','\0',
'S','t','r','i','n','g','N','o','C','o','o','r','d','i','n','a','t','e','s','\0',
's','t','r','i','n','g','N','o','D','a','t','e','\0',
'S','t','r','i','n','g','N','o','D','a','t','e','\0',
's','t','r','i','n','g','N','o','F','i','l','e','\0',
'S','t','r','i','n','g','N','o','F','i','l','e','\0',
's','t','r','i','n','g','N','o','P','r','i','n','t','C','o','m','m','a','n','d','\0',
'S','t','r','i','n','g','N','o','P','r','i','n','t','C','o','m','m','a','n','d','\0',
's','t','r','i','n','g','P','a','g','e','F','i','n','i','s','h','e','d','\0',
'S','t','r','i','n','g','P','a','g','e','F','i','n','i','s','h','e','d','\0',
's','t','r','i','n','g','U','n','k','n','o','w','n','\0',
'S','t','r','i','n','g','U','n','k','n','o','w','n','\0',
};

==> mgv-2.4.2.tar.gz: mgv-2.4.2/strdefs.c <==
/*
 * strdefs.c
 *	Extra string defs for MGv.
 *
 * Copyright (C) 1996  Eric A. Howe
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   Authors:	Matthew D. Francey
 *		Eric A. Howe (mu@trends.net)
 */
#include <wlib/rcs.h>
MU_ID("$Mu: mgv/strdefs.c,v 1.25 $")

const char mgv_strdefs[] = {
'a','n','t','i','a','l','i','a','s','E','P','S','\0',
'A','n','t','i','a','l','i','a','s','E','P','S','\0',
'a','u','t','o','H','e','i','g','h','t','\0',
'A','u','t','o','H','e','i','g','h','t','\0',
'a','u','t','o','W','i','d','t','h','\0',
'A','u','t','o','W','i','d','t','h','\0',
'b','u','n','z','i','p','\0',
'B','u','n','z','i','p','\0',
'b','z','i','p','\0',
'B','z','i','p','\0',
'c','o','n','f','i','r','m','E','x','i','t','\0',
'C','o','n','f','i','r','m','E','x','i','t','\0',
'd','e','c','o','m','p','r','e','s','s','\0',
'D','e','c','o','m','p','r','e','s','s','\0',
'c','o','m','p','r','e','s','s','\0',
'C','o','m','p','r','e','s','s','\0',
'd','e','f','a','u','l','t','P','a','g','e','M','e','d','i','a','\0',
'D','e','f','a','u','l','t','P','a','g','e','M','e','d','i','a','\0',
'P','a','g','e','M','e','d','i','a','\0',
'g','u','n','z','i','p','\0',
'G','u','n','z','i','p','\0',
'g','z','i','p','\0',
'G','z','i','p','\0',
'h','i','d','e','L','o','g','\0',
'H','i','d','e','L','o','g','\0',
'h','i','d','e','M','e','n','u','B','a','r','\0',
'H','i','d','e','M','e','n','u','B','a','r','\0',
'h','i','d','e','P','a','g','e','L','i','s','t','\0',
'H','i','d','e','P','a','g','e','L','i','s','t','\0',
'h','i','d','e','S','t','a','t','u','s','L','i','n','e','\0',
'H','i','d','e','S','t','a','t','u','s','L','i','n','e','\0',
'k','i','l','l','C','h','i','l','d','r','e','n','A','t','E','x','i','t','\0',
'K','i','l','l','C','h','i','l','d','r','e','n','A','t','E','x','i','t','\0',
'm','a','g','i','c','R','e','s','i','s','t','a','n','c','e','\0',
'M','a','g','i','c','R','e','s','i','s','t','a','n','c','e','\0',
'p','r','i','n','t','C','o','m','m','a','n','d','\0',
'P','r','i','n','t','C','o','m','m','a','n','d','\0',
'p','r','i','n','t','e','r','\0',
'P','r','i','n','t','e','r','\0',
'r','e','s','e','t','S','c','r','o','l','l','B','a','r','s','\0',
'R','e','s','e','t','S','c','r','o','l','l','B','a','r','s','\0',
'R','e','s','e','t','S','c','r','o','l','l','B','a','r','s','\0',
'r','e','t','i','c','u','l','e','F','o','r','e','g','r','o','u','n','d','\0',
'R','e','t','i','c','u','l','e','F','o','r','e','g','r','o','u','n','d','\0',
'r','e','t','i','c','u','l','e','L','i','n','e','W','i','d','t','h','\0',
'R','e','t','i','c','u','l','e','L','i','n','e','W','i','d','t','h','\0',
's','h','o','w','L','a','b','e','l','s','\0',
'S','h','o','w','L','a','b','e','l','s','\0',
's','h','o','w','P','a','g','e','N','u','m','b','e','r','s','\0',
'S','h','o','w','P','a','g','e','N','u','m','b','e','r','s','\0',
't','e','m','p','D','i','r','\0',
'T','e','m','p','D','i','r','\0',
'm','a','g','i','c','S','c','r','o','l','l','i','n','g','\0',
'M','a','g','i','c','S','c','r','o','l','l','i','n','g','\0',
's','m','o','o','t','h','S','c','r','o','l','l','i','n','g','\0',
'S','m','o','o','t','h','S','c','r','o','l','l','i','n','g','\0',
's','m','o','o','t','h','n','e','s','s','\0',
'S','m','o','o','t','h','n','e','s','s','\0',
'm','a','g','s','t','e','p','\0',
'M','a','g','s','t','e','p','\0',
's','m','a','r','t','S','i','z','i','n','g','\0',
'S','m','a','r','t','S','i','z','i','n','g','\0',
'w','m','W','i','d','t','h','\0',
'W','m','W','i','d','t','h','\0',
'w','m','H','e','i','g','h','t','\0',
'W','m','H','e','i','g','h','t','\0',
's','c','r','o','l','l','P','e','r','c','e','n','t','a','g','e','\0',
'S','c','r','o','l','l','P','e','r','c','e','n','t','a','g','e','\0',
'c','o','p','y','S','t','d','i','n','\0',
'C','o','p','y','S','t','d','i','n','\0',
's','t','r','i','n','g','B','a','d','A','r','g','u','m','e','n','t','\0',
'S','t','r','i','n','g','B','a','d','A','r','g','u','m','e','n','t','\0',
's','t','r','i','n','g','B','a','d','V','e','r','s','i','o','n','\0',
'S','t','r','i','n','g','B','a','d','V','e','r','s','i','o','n','\0',
's','t','r','i','n','g','C','a','n','t','A','l','l','o','c','P','i','x','m','a','p','\0',
'S','t','r','i','n','g','C','a','n','t','A','l','l','o','c','P','i','x','m','a','p','\0',
's','t','r','i','n','g','C','a','n','t','D','e','c','o','m','p','r','e','s','s','\0',
'S','t','r','i','n','g','C','a','n','t','D','e','c','o','m','p','r','e','s','s','\0',
's','t','r','i','n','g','C','a','n','t','H','i','d','e','M','e','n','u','\0',
'S','t','r','i','n','g','C','a','n','t','H','i','d','e','M','e','n','u','\0',
's','t','r','i','n','g','C','a','n','t','O','p','e','n','\0',
'S','t','r','i','n','g','C','a','n','t','O','p','e','n','\0',
's','t','r','i','n','g','C','a','n','t','P','r','i','n','t','\0',
'S','t','r','i','n','g','C','a','n','t','P','r','i','n','t','\0',
's','t','r','i','n','g','E','r','r','o','r','\0',
'S','t','r','i','n','g','E','r','r','o','r','\0',
's','t','r','i','n','g','F','i','l','e','E','x','i','s','t','s','\0',
'S','t','r','i','n','g','F','i','l','e','E','x','i','s','t','s','\0',
's','t','r','i','n','g','I','n','t','e','r','p','D','o','n','e','\0',
'S','t','r','i','n','g','I','n','t','e','r','p','D','o','n','e','\0',
's','t','r','i','n','g','I','n','t','e','r','p','F','a','i','l','e','d','\0',
'S','t','r','i','n','g','I','n','t','e','r','p','F','a','i','l','e','d','\0',
's','t','r','i','n','g','M','e','s','s','a','g','e','\0',
'S','t','r','i','n','g','M','e','s','s','a','g','e','\0',
's','t','r','i','n','g','N','o','C','o','o','r','d','i','n','a','t','e','s','\0',
'S','t','r','i','n','g','N','o','C','o','o','r','d','i','n','a','t','e','s','\0',
's','t','r','i','n','g','N','o','D','a','t','e','\0',
'S','t','r','i','n','g','N','o','D','a','t','e','\0',
's','t','r','i','n','g','N','o','F','i','l','e','\0',
'S','t','r','i','n','g','N','o','F','i','l','e','\0',
's','t','r','i','n','g','N','o','P','r','i','n','t','C','o','m','m','a','n','d','\0',
'S','t','r','i','n','g','N','o','P','r','i','n','t','C','o','m','m','a','n','d','\0',
's','t','r','i','n','g','P','a','g','e','F','i','n','i','s','h','e','d','\0',
'S','t','r','i','n','g','P','a','g','e','F','i','n','i','s','h','e','d','\0',
's','t','r','i','n','g','U','n','k','n','o','w','n','S','w','i','t','c','h','\0',
'S','t','r','i','n','g','U','n','k','n','o','w','n','S','w','i','t','c','h','\0',
's','t','r','i','n','g','P','S','\0',
'S','t','r','i','n','g','P','S','\0',
's','t','r','i','n','g','E','P','S','\0',
'S','t','r','i','n','g','E','P','S','\0',
's','t','r','i','n','g','P','D','F','\0',
'S','t','r','i','n','g','P','D','F','\0',
's','t','r','i','n','g','U','n','k','n','o','w','n','T','y','p','e','\0',
'S','t','r','i','n','g','U','n','k','n','o','w','n','T','y','p','e','\0',
's','t','r','i','n','g','U','n','k','n','o','w','n','M','e','d','i','a','\0',
'S','t','r','i','n','g','U','n','k','n','o','w','n','M','e','d','i','a','\0',
's','t','r','i','n','g','U','n','k','n','o','w','n','\0',
'S','t','r','i','n','g','U','n','k','n','o','w','n','\0',
};
